/// @addtogroup dynset
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file C0Set.h
///
/// @author The CAPD Group
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

#ifndef _CAPD_DYNSET_C0SET_H_ 
#define _CAPD_DYNSET_C0SET_H_ 

#include <string>
#include <sstream>
#include "capd/dynsys/DynSys.h"

namespace capd{
namespace dynset{

template<typename MatrixT>
class C0Set{
public:
  typedef MatrixT MatrixType;
  typedef typename MatrixType::RowVectorType VectorType;
  typedef typename MatrixType::ScalarType ScalarType;

  virtual ~C0Set (void) {}
  virtual C0Set *clone(void) = 0;
  virtual C0Set *fresh(void) = 0;
  virtual C0Set *cover(const VectorType& v)  = 0;
  virtual ScalarType size(void) = 0;
  virtual VectorType center(void) = 0;
  virtual void move(capd::dynsys::DynSys<MatrixType>& dynsys) = 0;
  virtual VectorType affineTransformation(const MatrixType&, const VectorType&) const = 0;

  virtual std::string show(void) const = 0;
  virtual operator VectorType() const = 0;
};

}} //namespace capd::dynset

#endif // _CAPD_DYNSET_C0SET_H_ 

/// @}
