/// @addtogroup dynset
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file C1Set.h
///
/// @author Daniel Wilczak
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

/* Author: Daniel Wilczak 2002-2004 */

#ifndef _CAPD_DYNSET_C1SET_H_ 
#define _CAPD_DYNSET_C1SET_H_ 

#include <string>

#include "capd/dynsys/C1DynSys.h"
#include "capd/vectalg/Norm.h"

namespace capd{
namespace dynset{

template<typename MatrixT>
class C1Set{
public:
  typedef MatrixT MatrixType;
  typedef typename MatrixType::RowVectorType VectorType;
  typedef typename MatrixType::ScalarType ScalarType;
  typedef capd::vectalg::Norm<VectorType,MatrixType> NormType;

  virtual C1Set* clone(void) const = 0;
  virtual C1Set* fresh(void) const = 0;
  virtual C1Set* cover(const VectorType &v) const = 0;
  virtual ~C1Set(){}

  virtual ScalarType size(void) const = 0;
  virtual VectorType center(void) const = 0;
  virtual void move(capd::dynsys::C1DynSys<MatrixType>& c1dynsys) = 0;

  virtual const NormType* getNorm(void) const = 0;

  virtual std::string show(void) const = 0;
  virtual operator VectorType() const = 0;
  virtual operator MatrixType() const = 0;
};

}} // the end of the namespace capd::dynset

#endif // _CAPD_DYNSET_C1SET_H_ 

/// @}
