/// @addtogroup dynset
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file RectSet.h
///
/// @author The CAPD Group
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

#ifndef _CAPD_DYNSET_RECTSET_H_ 
#define _CAPD_DYNSET_RECTSET_H_ 

#include "capd/dynset/C0Set.h"

// RectSet   - set is represented as  x + B*r
//      move - via QR-decomposition

namespace capd{
namespace dynset{

template<typename MatrixT>
class RectSet : public C0Set<MatrixT>{

public:
  typedef MatrixT MatrixType;
  typedef typename MatrixType::RowVectorType VectorType;
  typedef typename MatrixType::ScalarType ScalarType;
  typedef capd::vectalg::Norm<VectorType,MatrixType> NormType;

  inline VectorType get_x () {return m_x;}
  inline VectorType get_r () {return m_r;}
  inline MatrixType get_B () {return m_B;}

  explicit RectSet(int);
  explicit RectSet(const VectorType& x);
  RectSet(const VectorType& x, const VectorType& r);
  RectSet(const VectorType& x, const VectorType& r, const MatrixType& B);

  ScalarType size(void);
  C0Set<MatrixType>* clone(void);
  C0Set<MatrixType>* fresh(void);
  C0Set<MatrixType>* cover(const VectorType& v);
  VectorType center(void);
  void move(capd::dynsys::DynSys<MatrixType>& dynsys);
  void move(capd::dynsys::DynSys<MatrixType>& dynsys, RectSet& result) const;
  virtual std::string show(void) const;
  operator VectorType() const;
  virtual VectorType affineTransformation(const MatrixType&, const VectorType&) const;

protected:
  VectorType m_x, m_r;
  MatrixType m_B;
};

// inline definitions


template<typename MatrixType>
inline typename RectSet<MatrixType>::VectorType RectSet<MatrixType>::center(void)
{
  return m_x;
}

template<typename MatrixT>
inline RectSet<MatrixT>::operator typename RectSet<MatrixT>::VectorType(void) const
{
  return m_x + m_B*m_r;
}

template<typename MatrixType>
inline C0Set<MatrixType>* RectSet<MatrixType>::clone(void)
{
  return new RectSet(*this);
}

template<typename MatrixType>
inline C0Set<MatrixType>* RectSet<MatrixType>::fresh(void)
{
  return new RectSet(m_x.dimension());
}

template<typename MatrixType>
inline C0Set<MatrixType>* RectSet<MatrixType>::cover(const VectorType& v)
{
  return new RectSet(midVector(v),v-midVector(v));
}

}} // namespace capd::dynset

#endif // _CAPD_DYNSET_RECTSET_H_ 

/// @}
