/// @addtogroup dynsys
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file dynsysLib.h
///
/// @author Daniel Wilczak
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

/* Author: Daniel Wilczak 2005 */

#ifndef _CAPD_DYNSYS_DYNSYSLIB_H_ 
#define _CAPD_DYNSYS_DYNSYSLIB_H_ 

#include "capd/capd/factrial.h"
#include "capd/map/Map.h"
#include "capd/map/C2Map.h"
#include "capd/map/CnMap.h"
#include "capd/dynsys/TaylorException.h"
#include "capd/dynsys/C2Taylor.h"
#include "capd/dynsys/CnTaylor.h"
#include "capd/dynsys/Linear2d.h"
#include "capd/dynsys/Linear3d.h"
#include "capd/dynsys/VLin3D.h"
#include "capd/dynsys/OdeNumTaylor.h"
#include "capd/vectalg/vectalgLib.h"
#include "capd/map/mapLib.h"

typedef capd::dynsys::DynSys<IMatrix> DynSys;
typedef capd::dynsys::Ode<IMatrix> Ode;
typedef capd::dynsys::OdeNum<IMatrix> OdeNum;
typedef capd::dynsys::OdeNumTaylor<IMatrix> OdeNumTaylor;
typedef capd::dynsys::VLin3D<IMatrix> VLin3D;
typedef capd::dynsys::Linear2d<IMatrix> linear2d;
typedef capd::dynsys::Linear3d<IMatrix> linear3d;
typedef capd::dynsys::Taylor<IMap> Taylor;
typedef capd::dynsys::C2Taylor<IC2Map> C2Taylor;
typedef capd::dynsys::CnTaylor<ICnMap> CnTaylor;
typedef capd::dynsys::TaylorException<IVector> TaylorException;

// classes for nonrigorous computations
typedef capd::dynsys::BasicTaylor<DMap> BasicTaylor;
typedef capd::dynsys::BasicC2Taylor<DC2Map> BasicC2Taylor;
typedef capd::dynsys::BasicCnTaylor<DCnMap> BasicCnTaylor;



typedef capd::dynsys::DynSys<IMatrixMD> DynSysMD;
typedef capd::dynsys::Ode<IMatrixMD> OdeMD;
typedef capd::dynsys::OdeNum<IMatrixMD> OdeNumMD;
typedef capd::dynsys::OdeNumTaylor<IMatrixMD> OdeNumTaylorMD;
typedef capd::dynsys::VLin3D<IMatrixMD> VLin3DMD;
typedef capd::dynsys::Linear2d<IMatrixMD> linear2dMD;
typedef capd::dynsys::Linear3d<IMatrixMD> linear3dMD;
typedef capd::dynsys::Taylor<IMapMD> TaylorMD;
typedef capd::dynsys::C2Taylor<IC2MapMD> C2TaylorMD;
typedef capd::dynsys::CnTaylor<ICnMapMD> CnTaylorMD;
typedef capd::dynsys::TaylorException<IVectorMD> TaylorExceptionMD;

// classes for nonrigorous computations
typedef capd::dynsys::BasicTaylor<DMapMD> BasicTaylorMD;
typedef capd::dynsys::BasicC2Taylor<DC2MapMD> BasicC2TaylorMD;
typedef capd::dynsys::BasicCnTaylor<DCnMapMD> BasicCnTaylorMD;



#ifdef __HAVE_MPFR__

  typedef capd::dynsys::DynSys<IMpMatrix> MpDynSys;
  typedef capd::dynsys::Ode<IMpMatrix> MpOde;
  typedef capd::dynsys::OdeNum<IMpMatrix> MpOdeNum;
  typedef capd::dynsys::OdeNumTaylor<IMpMatrix> MpOdeNumTaylor;
  typedef capd::dynsys::VLin3D<IMpMatrix> MpVLin3D;
  typedef capd::dynsys::Linear2d<IMpMatrix> MpLinear2d;
  typedef capd::dynsys::Linear3d<IMpMatrix> MpLinear3d;
  typedef capd::dynsys::Taylor<IMpMap> MpTaylor;
  typedef capd::dynsys::C2Taylor<IMpC2Map> MpC2Taylor;
  typedef capd::dynsys::CnTaylor<IMpCnMap> MpCnTaylor;
  typedef capd::dynsys::TaylorException<IMpVector> MpTaylorException;

  // classes for nonrigorous computations
  typedef capd::dynsys::BasicTaylor<MpMap> MpBasicTaylor;
  typedef capd::dynsys::BasicC2Taylor<MpC2Map> MpBasicC2Taylor;
  typedef capd::dynsys::BasicCnTaylor<MpCnMap> MpBasicCnTaylor;



  typedef capd::dynsys::DynSys<IMpMatrixMD> MpDynSysMD;
  typedef capd::dynsys::Ode<IMpMatrixMD> MpOdeMD;
  typedef capd::dynsys::OdeNum<IMpMatrixMD> MpOdeNumMD;
  typedef capd::dynsys::OdeNumTaylor<IMpMatrixMD> MpOdeNumTaylorMD;
  typedef capd::dynsys::VLin3D<IMpMatrixMD> MpVLin3DMD;
  typedef capd::dynsys::Linear2d<IMpMatrixMD> MpLinear2dMD;
  typedef capd::dynsys::Linear3d<IMpMatrixMD> MpLinear3dMD;
  typedef capd::dynsys::Taylor<IMpMapMD> MpTaylorMD;
  typedef capd::dynsys::C2Taylor<IMpC2MapMD> MpC2TaylorMD;
  typedef capd::dynsys::CnTaylor<IMpCnMapMD> MpCnTaylorMD;
  typedef capd::dynsys::TaylorException<IMpVectorMD> MpTaylorExceptionMD;

  // classes for nonrigorous computations
  typedef capd::dynsys::BasicTaylor<MpMapMD> MpBasicTaylorMD;
  typedef capd::dynsys::BasicC2Taylor<MpC2MapMD> MpBasicC2TaylorMD;
  typedef capd::dynsys::BasicCnTaylor<MpCnMapMD> MpBasicCnTaylorMD;

#endif

#endif // _CAPD_DYNSYS_DYNSYSLIB_H_ 

/// @}
