/// @addtogroup matrixAlgorithms
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file floatMatrixAlgorithms.cpp
///
/// @author The CAPD Group
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

#include "capd/capd/minmax.h"
#include "capd/vectalg/vectalgLib.h"
#include "capd/matrixAlgorithms/floatMatrixAlgorithms.hpp"

template void capd::matrixAlgorithms::orthonormalize<DMatrix>(DMatrix&);
template void capd::matrixAlgorithms::orthonormalize<IMatrix>(IMatrix&);

template void capd::matrixAlgorithms::QR_decompose<DMatrix>(const DMatrix&,DMatrix&,DMatrix&);
template void capd::matrixAlgorithms::QR_decompose<IMatrix>(const IMatrix&,IMatrix&,IMatrix&);

template int capd::matrixAlgorithms::symMatrixDiagonalize<DMatrix>(const DMatrix&,DMatrix&,double);
template int capd::matrixAlgorithms::symMatrixDiagonalize<IMatrix>(const IMatrix&,IMatrix&,interval);

template double capd::matrixAlgorithms::spectralRadiusOfSymMatrix<DMatrix>(const DMatrix&,double);
template interval capd::matrixAlgorithms::spectralRadiusOfSymMatrix<IMatrix>(const IMatrix&,interval);

template double capd::matrixAlgorithms::maxEigenValueOfSymMatrix<DMatrix>(const DMatrix&,double);
template interval capd::matrixAlgorithms:: maxEigenValueOfSymMatrix<IMatrix>(const IMatrix&,interval);

template DVector capd::matrixAlgorithms::gauss<DMatrix,DVector>(DMatrix,DVector);
template IVector capd::matrixAlgorithms::gauss<IMatrix,IVector>(IMatrix,IVector);

template void capd::matrixAlgorithms::croutDecomposition<DMatrix>(const DMatrix&,DMatrix&,DMatrix&);
template void capd::matrixAlgorithms::croutDecomposition<IMatrix>(const IMatrix&,IMatrix&,IMatrix&);

template DMatrix capd::matrixAlgorithms::invLowerTriangleMatrix<DMatrix>(const DMatrix&);
template IMatrix capd::matrixAlgorithms::invLowerTriangleMatrix<IMatrix>(const IMatrix&);

template DMatrix capd::matrixAlgorithms::invUpperTriangleMatrix<DMatrix>(const DMatrix&);
template IMatrix capd::matrixAlgorithms::invUpperTriangleMatrix<IMatrix>(const IMatrix&);

template DMatrix capd::matrixAlgorithms::inverseMatrix<DMatrix>(const DMatrix&);
template IMatrix capd::matrixAlgorithms::inverseMatrix<IMatrix>(const IMatrix&);

template DMatrix capd::matrixAlgorithms::gaussInverseMatrix<DMatrix>(const DMatrix);
template IMatrix capd::matrixAlgorithms::gaussInverseMatrix<IMatrix>(const IMatrix);





template void capd::matrixAlgorithms::orthonormalize<DMatrixMD>(DMatrixMD&);
template void capd::matrixAlgorithms::orthonormalize<IMatrixMD>(IMatrixMD&);

template void capd::matrixAlgorithms::QR_decompose<DMatrixMD>(const DMatrixMD&,DMatrixMD&,DMatrixMD&);
template void capd::matrixAlgorithms::QR_decompose<IMatrixMD>(const IMatrixMD&,IMatrixMD&,IMatrixMD&);

template int capd::matrixAlgorithms::symMatrixDiagonalize<DMatrixMD>(const DMatrixMD&,DMatrixMD&,double);
template int capd::matrixAlgorithms::symMatrixDiagonalize<IMatrixMD>(const IMatrixMD&,IMatrixMD&,interval);

template double capd::matrixAlgorithms::spectralRadiusOfSymMatrix<DMatrixMD>(const DMatrixMD&,double);
template interval capd::matrixAlgorithms::spectralRadiusOfSymMatrix<IMatrixMD>(const IMatrixMD&,interval);

template double capd::matrixAlgorithms::maxEigenValueOfSymMatrix<DMatrixMD>(const DMatrixMD&,double);
template interval capd::matrixAlgorithms:: maxEigenValueOfSymMatrix<IMatrixMD>(const IMatrixMD&,interval);

template DVectorMD capd::matrixAlgorithms::gauss<DMatrixMD,DVectorMD>(DMatrixMD,DVectorMD);
template IVectorMD capd::matrixAlgorithms::gauss<IMatrixMD,IVectorMD>(IMatrixMD,IVectorMD);

template void capd::matrixAlgorithms::croutDecomposition<DMatrixMD>(const DMatrixMD&,DMatrixMD&,DMatrixMD&);
template void capd::matrixAlgorithms::croutDecomposition<IMatrixMD>(const IMatrixMD&,IMatrixMD&,IMatrixMD&);

template DMatrixMD capd::matrixAlgorithms::invLowerTriangleMatrix<DMatrixMD>(const DMatrixMD&);
template IMatrixMD capd::matrixAlgorithms::invLowerTriangleMatrix<IMatrixMD>(const IMatrixMD&);

template DMatrixMD capd::matrixAlgorithms::invUpperTriangleMatrix<DMatrixMD>(const DMatrixMD&);
template IMatrixMD capd::matrixAlgorithms::invUpperTriangleMatrix<IMatrixMD>(const IMatrixMD&);

template DMatrixMD capd::matrixAlgorithms::inverseMatrix<DMatrixMD>(const DMatrixMD&);
template IMatrixMD capd::matrixAlgorithms::inverseMatrix<IMatrixMD>(const IMatrixMD&);

template DMatrixMD capd::matrixAlgorithms::gaussInverseMatrix<DMatrixMD>(const DMatrixMD);
template IMatrixMD capd::matrixAlgorithms::gaussInverseMatrix<IMatrixMD>(const IMatrixMD);


#ifdef __HAVE_MPFR__

  template void capd::matrixAlgorithms::orthonormalize<MpMatrix>(MpMatrix&);
  template void capd::matrixAlgorithms::orthonormalize<IMpMatrix>(IMpMatrix&);

  template void capd::matrixAlgorithms::QR_decompose<MpMatrix>(const MpMatrix&,MpMatrix&,MpMatrix&);
  template void capd::matrixAlgorithms::QR_decompose<IMpMatrix>(const IMpMatrix&,IMpMatrix&,IMpMatrix&);

  template int capd::matrixAlgorithms::symMatrixDiagonalize<MpMatrix>(const MpMatrix&,MpMatrix&,Real);
  template int capd::matrixAlgorithms::symMatrixDiagonalize<IMpMatrix>(const IMpMatrix&,IMpMatrix&,MpInterval);

  template Real capd::matrixAlgorithms::spectralRadiusOfSymMatrix<MpMatrix>(const MpMatrix&,Real);
  template MpInterval capd::matrixAlgorithms::spectralRadiusOfSymMatrix<IMpMatrix>(const IMpMatrix&,MpInterval);

  template Real capd::matrixAlgorithms::maxEigenValueOfSymMatrix<MpMatrix>(const MpMatrix&,Real);
  template MpInterval capd::matrixAlgorithms:: maxEigenValueOfSymMatrix<IMpMatrix>(const IMpMatrix&,MpInterval);

  template MpVector capd::matrixAlgorithms::gauss<MpMatrix,MpVector>(MpMatrix,MpVector);
  template IMpVector capd::matrixAlgorithms::gauss<IMpMatrix,IMpVector>(IMpMatrix,IMpVector);

  template void capd::matrixAlgorithms::croutDecomposition<MpMatrix>(const MpMatrix&,MpMatrix&,MpMatrix&);
  template void capd::matrixAlgorithms::croutDecomposition<IMpMatrix>(const IMpMatrix&,IMpMatrix&,IMpMatrix&);

  template MpMatrix capd::matrixAlgorithms::invLowerTriangleMatrix<MpMatrix>(const MpMatrix&);
  template IMpMatrix capd::matrixAlgorithms::invLowerTriangleMatrix<IMpMatrix>(const IMpMatrix&);

  template MpMatrix capd::matrixAlgorithms::invUpperTriangleMatrix<MpMatrix>(const MpMatrix&);
  template IMpMatrix capd::matrixAlgorithms::invUpperTriangleMatrix<IMpMatrix>(const IMpMatrix&);

  template MpMatrix capd::matrixAlgorithms::inverseMatrix<MpMatrix>(const MpMatrix&);
  template IMpMatrix capd::matrixAlgorithms::inverseMatrix<IMpMatrix>(const IMpMatrix&);

  template MpMatrix capd::matrixAlgorithms::gaussInverseMatrix<MpMatrix>(const MpMatrix);
  template IMpMatrix capd::matrixAlgorithms::gaussInverseMatrix<IMpMatrix>(const IMpMatrix);





  template void capd::matrixAlgorithms::orthonormalize<MpMatrixMD>(MpMatrixMD&);
  template void capd::matrixAlgorithms::orthonormalize<IMpMatrixMD>(IMpMatrixMD&);

  template void capd::matrixAlgorithms::QR_decompose<MpMatrixMD>(const MpMatrixMD&,MpMatrixMD&,MpMatrixMD&);
  template void capd::matrixAlgorithms::QR_decompose<IMpMatrixMD>(const IMpMatrixMD&,IMpMatrixMD&,IMpMatrixMD&);

  template int capd::matrixAlgorithms::symMatrixDiagonalize<MpMatrixMD>(const MpMatrixMD&,MpMatrixMD&,Real);
  template int capd::matrixAlgorithms::symMatrixDiagonalize<IMpMatrixMD>(const IMpMatrixMD&,IMpMatrixMD&,MpInterval);

  template Real capd::matrixAlgorithms::spectralRadiusOfSymMatrix<MpMatrixMD>(const MpMatrixMD&,Real);
  template MpInterval capd::matrixAlgorithms::spectralRadiusOfSymMatrix<IMpMatrixMD>(const IMpMatrixMD&,MpInterval);

  template Real capd::matrixAlgorithms::maxEigenValueOfSymMatrix<MpMatrixMD>(const MpMatrixMD&,Real);
  template MpInterval capd::matrixAlgorithms:: maxEigenValueOfSymMatrix<IMpMatrixMD>(const IMpMatrixMD&,MpInterval);

  template MpVectorMD capd::matrixAlgorithms::gauss<MpMatrixMD,MpVectorMD>(MpMatrixMD,MpVectorMD);
  template IMpVectorMD capd::matrixAlgorithms::gauss<IMpMatrixMD,IMpVectorMD>(IMpMatrixMD,IMpVectorMD);

  template void capd::matrixAlgorithms::croutDecomposition<MpMatrixMD>(const MpMatrixMD&,MpMatrixMD&,MpMatrixMD&);
  template void capd::matrixAlgorithms::croutDecomposition<IMpMatrixMD>(const IMpMatrixMD&,IMpMatrixMD&,IMpMatrixMD&);

  template MpMatrixMD capd::matrixAlgorithms::invLowerTriangleMatrix<MpMatrixMD>(const MpMatrixMD&);
  template IMpMatrixMD capd::matrixAlgorithms::invLowerTriangleMatrix<IMpMatrixMD>(const IMpMatrixMD&);

  template MpMatrixMD capd::matrixAlgorithms::invUpperTriangleMatrix<MpMatrixMD>(const MpMatrixMD&);
  template IMpMatrixMD capd::matrixAlgorithms::invUpperTriangleMatrix<IMpMatrixMD>(const IMpMatrixMD&);

  template MpMatrixMD capd::matrixAlgorithms::inverseMatrix<MpMatrixMD>(const MpMatrixMD&);
  template IMpMatrixMD capd::matrixAlgorithms::inverseMatrix<IMpMatrixMD>(const IMpMatrixMD&);

  template MpMatrixMD capd::matrixAlgorithms::gaussInverseMatrix<MpMatrixMD>(const MpMatrixMD);
  template IMpMatrixMD capd::matrixAlgorithms::gaussInverseMatrix<IMpMatrixMD>(const IMpMatrixMD);

#endif

/// @}
