/// @addtogroup vectalg
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file MpVector.cpp
///
/// @author The CAPD Group
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file constitutes a part of the CAPD library, 
// distributed under the terms of the GNU General Public License.
// Consult  http://capd.wsb-nlu.edu.pl/ for details. 

#ifdef __HAVE_MPFR__

#include <iostream>
#include "capd/vectalg/Dimension.h"
#include "capd/vectalg/Vector.hpp"
#include "capd/vectalg/vectalgLib.h"

namespace capd{ 
  namespace vectalg{


template class Vector<Real,DIM>;

template Vector<Real,DIM> abs<Real,DIM> (const Vector<Real,DIM> &v);
template Vector<Real,DIM> operator- <Real,DIM> (const Vector<Real,DIM> &v);
template Vector<Real,DIM> operator+ <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template Vector<Real,DIM> operator- <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template Real operator* <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);

template Vector<Real,DIM> operator* <Real,Real,DIM> (const Vector<Real,DIM> &v,const Real &s);
template Vector<Real,DIM> operator* <Real,Real,DIM> (const Real &s,const Vector<Real,DIM> &v);
template Vector<Real,DIM> operator/ <Real,Real,DIM> (const Vector<Real,DIM> &v, const Real &s);

template Vector<Real,DIM> operator* <Real,long,DIM>(const Vector<Real,DIM> &v,const long &s);
template Vector<Real,DIM> operator* <Real,long,DIM>(const long &s,const Vector<Real,DIM> &v);
template Vector<Real,DIM> operator/ <Real,long,DIM>(const Vector<Real,DIM> &v, const long &s);

template Vector<Real,DIM> operator* <Real,int,DIM>(const Vector<Real,DIM> &v,const int &s);
template Vector<Real,DIM> operator* <Real,int,DIM>(const int &s,const Vector<Real,DIM> &v);
template Vector<Real,DIM> operator/ <Real,int,DIM>(const Vector<Real,DIM> &v, const int &s);

template Vector<Real,DIM> operator+ <Real,DIM> (const Vector<Real,DIM> &v,const Real &s);
template Vector<Real,DIM> operator- <Real,DIM> (const Vector<Real,DIM> &v,const Real &s);
template bool operator < <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template bool operator > <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template bool operator<= <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template bool operator>= <Real,DIM> (const Vector<Real,DIM> &v1,const Vector<Real,DIM> &v2);
template std::ostream &operator<< <Real,DIM> (std::ostream &out, const Vector<Real,DIM> &v);
template std::istream &operator>> <Real,DIM>(std::istream &inp, Vector<Real,DIM> &v);

}}  // end of namespace capd::vectalg

#endif // __HAVE_MPFR__

/// @}
